@@ -26,6 +26,6 @@
 #define SYSTEM_EXPAT
 #define ENABLE_SOUND
 /* #undef USE_AEONWAVE */
-#define ENABLE_SIMD
+/* #undef ENABLE_SIMD */
 /* #undef ENABLE_SIMD_CODE */
 /* #undef ENABLE_GDAL */
